@@ -8,7 +8,7 @@ import torch.nn.functional as F
 from torch.autograd import Function
 
 from . import extra as ex
-from .number import directquant
+from .number import directquant, alldirectquant
 
 
 class Adder2d(ex.Adder2d):
@@ -19,10 +19,14 @@ class Adder2d(ex.Adder2d):
                  stride=1,
                  padding=0,
                  bias=False,
-                 weight_bit_width=8,
-                 bias_bit_width=16,
-                 input_bit_width=8,
-                 output_bit_width=12,
+                 weight_dec_bit_width=8,
+                 bias_dec_bit_width=16,
+                 input_dec_bit_width=8,
+                 output_dec_bit_width=12,
+                 weight_all_bit_width=8,
+                 bias_all_bit_width=16,
+                 input_all_bit_width=8,
+                 output_all_bit_width=12,
                  iostrict=False):
         super().__init__(input_channel,
                          output_channel,
@@ -30,27 +34,35 @@ class Adder2d(ex.Adder2d):
                          stride=stride,
                          padding=padding,
                          bias=bias)
-        self.weight_bit_width = weight_bit_width
-        self.bias_bit_width = bias_bit_width
-        self.input_bit_width = input_bit_width
-        self.output_bit_width = output_bit_width
+        self.weight_all_bit_width = weight_all_bit_width
+        self.bias_all_bit_width = bias_all_bit_width
+        self.input_all_bit_width = input_all_bit_width
+        self.output_all_bit_width = output_all_bit_width
+        self.weight_dec_bit_width = weight_dec_bit_width
+        self.bias_dec_bit_width = bias_dec_bit_width
+        self.input_dec_bit_width = input_dec_bit_width
+        self.output_dec_bit_width = output_dec_bit_width
         self.iostrict = iostrict
 
     def adder_forward(self, input):
         if self.iostrict is True:
-            input = directquant(input, self.input_bit_width)
+            input = alldirectquant(input, self.input_dec_bit_width,
+                                   self.input_all_bit_width)
         if self.bias is None:
             bias = None
         else:
-            bias = directquant(self.bias, self.bias_bit_width)
-        weight = directquant(self.weight, self.weight_bit_width)
+            bias = alldirectquant(self.bias, self.bias_dec_bit_width,
+                                  self.bias_all_bit_width)
+        weight = alldirectquant(self.weight, self.weight_dec_bit_width,
+                                self.weight_all_bit_width)
         output = ex.adder2d_function(input,
                                      weight,
                                      bias,
                                      stride=self.stride,
                                      padding=self.padding)
         if self.iostrict is True:
-            output = directquant(output, self.output_bit_width)
+            output = alldirectquant(output, self.output_dec_bit_width,
+                                    self.output_all_bit_width)
         return output
 
     def forward(self, input):
